@@ -4,12 +4,13 @@ package PITA::Scheme::Perl5::Build;
 
 use strict;
 use base 'PITA::Scheme::Perl';
-use File::Spec ();
-use Carp       ();
+use Carp        ();
+use File::Spec  ();
+use File::Which ();
 
 use vars qw{$VERSION};
 BEGIN {
-	$VERSION = '0.08';
+	$VERSION = '0.09';
 }
 
 
@@ -19,6 +20,10 @@ BEGIN {
 #####################################################################
 # Constructor
 
+sub default_path {
+	File::Which::which('perl') || '';
+}
+
 sub new {
 	my $class = shift;
 	my $self  = $class->SUPER::new(@_);
