@@ -4,11 +4,12 @@ package PITA::Scheme::Perl5::Make;
 
 use strict;
 use base 'PITA::Scheme::Perl';
-use Carp ();
+use Carp        ();
+use File::Which ();
 
 use vars qw{$VERSION};
 BEGIN {
-	$VERSION = '0.08';
+	$VERSION = '0.09';
 }
 
 
@@ -18,6 +19,10 @@ BEGIN {
 #####################################################################
 # Constructor
 
+sub default_path {
+	File::Which::which('perl') || '';
+}
+
 sub new {
 	my $class = shift;
 	my $self  = $class->SUPER::new(@_);
